# Generated by Django 4.2.11 on 2024-05-21 11:58

from django.conf import settings
import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("flow", "0026_create_unaccent_full_text_search_config"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Variant",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("species", models.CharField(max_length=50)),
                ("genome_assembly", models.CharField(max_length=20)),
                ("chromosome", models.CharField(max_length=20)),
                ("position", models.PositiveBigIntegerField()),
                ("reference", models.CharField(max_length=100)),
                ("alternative", models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name="VariantAnnotation",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "type",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("SNP", "SNP"),
                            ("INDEL", "INDEL"),
                            ("MIXED", "MIXED"),
                            ("MNP", "MNP"),
                            ("SYMBOLIC", "SYMBOLIC"),
                        ],
                        max_length=100,
                        null=True,
                    ),
                ),
                (
                    "clinical_diagnosis",
                    models.CharField(blank=True, max_length=200, null=True),
                ),
                (
                    "clinical_significance",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
                ("dbsnp_id", models.CharField(blank=True, max_length=20, null=True)),
                ("clinvar_id", models.CharField(blank=True, max_length=20, null=True)),
                (
                    "data",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="variant_annotations",
                        to="flow.data",
                    ),
                ),
                (
                    "variant",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="annotation",
                        to="resolwe_bio_variants.variant",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="VariantExperiment",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("variant_data_source", models.CharField(max_length=100)),
                ("timestamp", models.DateTimeField(auto_now_add=True, db_index=True)),
                (
                    "contributor",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="VariantCall",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("quality", models.FloatField(blank=True, null=True)),
                ("depth_norm_quality", models.FloatField(blank=True, null=True)),
                (
                    "unfiltered_allele_depth",
                    models.PositiveIntegerField(blank=True, null=True),
                ),
                ("depth", models.PositiveIntegerField(blank=True, null=True)),
                ("genotype", models.CharField(blank=True, max_length=3, null=True)),
                (
                    "genotype_quality",
                    models.PositiveIntegerField(blank=True, null=True),
                ),
                ("filter", models.CharField(blank=True, max_length=20, null=True)),
                (
                    "data",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="variant_calls",
                        to="flow.data",
                    ),
                ),
                (
                    "experiment",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="variant_calls",
                        to="resolwe_bio_variants.variantexperiment",
                    ),
                ),
                (
                    "sample",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="variant_calls",
                        to="flow.entity",
                    ),
                ),
                (
                    "variant",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="variant_calls",
                        to="resolwe_bio_variants.variant",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="VariantAnnotationTranscript",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("annotation", models.CharField(max_length=200)),
                ("annotation_impact", models.CharField(max_length=20)),
                ("gene", models.CharField(max_length=100)),
                ("protein_impact", models.CharField(max_length=100)),
                (
                    "transcript_ids",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=200),
                        default=list,
                        size=None,
                    ),
                ),
                ("canonical", models.BooleanField(default=False)),
                (
                    "variant_annotation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="transcripts",
                        to="resolwe_bio_variants.variantannotation",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.AddConstraint(
            model_name="variant",
            constraint=models.UniqueConstraint(
                fields=(
                    "species",
                    "genome_assembly",
                    "chromosome",
                    "position",
                    "reference",
                    "alternative",
                ),
                name="uniq_composite_key_variants",
            ),
        ),
    ]
